<?php

/**
 * Test: NDebugger::dump() basic types in HTML and text mode.
 *
 * @author     David Grudl
 * @package    Nette\Diagnostics
 * @subpackage UnitTests
 */



require dirname(__FILE__) . '/../bootstrap.php';



NDebugger::$consoleColors = NULL;
NDebugger::$productionMode = FALSE;



class Test
{
	public $x = array(10, NULL);

	private $y = 'hello';

	protected $z = 30;
}


// HTML mode

NDebugger::$consoleMode = FALSE;

Assert::match( '<pre class="nette-dump"><span class="php-null">NULL</span>
</pre>', NDebugger::dump(NULL, TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-bool">TRUE</span>
</pre>', NDebugger::dump(TRUE, TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-bool">FALSE</span>
</pre>', NDebugger::dump(FALSE, TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-int">0</span>
</pre>', NDebugger::dump(0, TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-int">1</span>
</pre>', NDebugger::dump(1, TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-float">0.0</span>
</pre>', NDebugger::dump(0.0, TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-float">0.1</span>
</pre>', NDebugger::dump(0.1, TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-string">""</span>
</pre>', NDebugger::dump('', TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-string">"0"</span>
</pre>', NDebugger::dump('0', TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-string">"\\x00"</span>
</pre>', NDebugger::dump("\x00", TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-array">array</span>(5) <code>[
   <span class="php-key">0</span> => <span class="php-int">1</span>
   <span class="php-key">1</span> => <span class="php-string">"hello"</span> (5)
   <span class="php-key">2</span> => <span class="php-array">array</span>(0)
   <span class="php-key">3</span> => <span class="php-array">array</span>(2) <code>[
      <span class="php-key">0</span> => <span class="php-int">1</span>
      <span class="php-key">1</span> => <span class="php-int">2</span>
   ]</code>
   <span class="php-key">4</span> => <span class="php-array">array</span>(2) <code>{
      <span class="php-key">1</span> => <span class="php-int">1</span>
      <span class="php-key">2</span> => <span class="php-int">2</span>
   }</code>
]</code>
</pre>
', NDebugger::dump(array(1, 'hello', array(), array(1, 2), array(1 => 1, 2)), TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-resource">stream resource</span>
</pre>', NDebugger::dump(fopen(__FILE__, 'r'), TRUE) );

Assert::match( '<pre class="nette-dump"><span class="php-object">stdClass</span>(0)
</pre>', NDebugger::dump((object) NULL, TRUE) );

$obj = new Test;
Assert::same(NDebugger::dump($obj), $obj);


// Text mode

NDebugger::$consoleMode = TRUE;

Assert::match( 'NULL', NDebugger::dump(NULL, TRUE) );

Assert::match( 'TRUE', NDebugger::dump(TRUE, TRUE) );

Assert::match( 'FALSE', NDebugger::dump(FALSE, TRUE) );

Assert::match( '0', NDebugger::dump(0, TRUE) );

Assert::match( '1', NDebugger::dump(1, TRUE) );

Assert::match( '0.0', NDebugger::dump(0.0, TRUE) );

Assert::match( '0.1', NDebugger::dump(0.1, TRUE) );

Assert::match( '""', NDebugger::dump('', TRUE) );

Assert::match( '"0"', NDebugger::dump('0', TRUE) );

Assert::match( '"\\x00"', NDebugger::dump("\x00", TRUE) );

Assert::match( 'array(5) [
   0 => 1
   1 => "hello" (5)
   2 => array(0)
   3 => array(2) [
      0 => 1
      1 => 2
   ]
   4 => array(2) {
      1 => 1
      2 => 2
   }
]
', NDebugger::dump(array(1, 'hello', array(), array(1, 2), array(1 => 1, 2)), TRUE) );

Assert::match( 'stream resource', NDebugger::dump(fopen(__FILE__, 'r'), TRUE) );

Assert::match( 'stdClass(0)', NDebugger::dump((object) NULL, TRUE) );

Assert::match( 'Test(3) {
   x => array(2) [
      0 => 10
      1 => NULL
   ]
   y private => "hello" (5)
   z protected => 30
}
', NDebugger::dump($obj, TRUE) );
