<?php

/**
 * Test: NPhpHelpers::format() & formatArgs()
 *
 * @author     David Grudl
 * @package    Nette\Utils
 * @subpackage UnitTests
 */



require dirname(__FILE__) . '/../bootstrap.php';


Assert::same( 'func', NPhpHelpers::format('func') );
Assert::same( 'func(1)', NPhpHelpers::format('func(?)', 1, 2) );

Assert::same( 'func', NPhpHelpers::formatArgs('func', array(1, 2)) );
Assert::same( 'func(1)', NPhpHelpers::formatArgs('func(?)', array(1, 2)) );
Assert::same( "func(array(\n\t1,\n\t2,\n))", NPhpHelpers::formatArgs('func(?)', array(array(1, 2))) );
Assert::same( 'func(1, 2)', NPhpHelpers::formatArgs('func(?*)', array(array(1, 2))) );

Assert::throws(create_function('', '
	NPhpHelpers::formatArgs(\'func(?*)\', array(1, 2));
'), 'InvalidArgumentException', 'Argument must be an array.');

Assert::throws(create_function('', '
	NPhpHelpers::formatArgs(\'func(?, ?, ?)\', array(1, 2));
'), 'InvalidArgumentException', 'Insufficient number of arguments.');

Assert::same( '$a = 2', NPhpHelpers::formatArgs('$? = ?', array('a', 2)) );
Assert::same( '$obj->a = 2', NPhpHelpers::formatArgs('$obj->? = ?', array('a', 2)) );
Assert::same( '$obj->{1} = 2', NPhpHelpers::formatArgs('$obj->? = ?', array(1, 2)) );
Assert::same( '$obj->{\' \'} = 2', NPhpHelpers::formatArgs('$obj->? = ?', array(' ', 2)) );

Assert::same( "Item", NPhpHelpers::formatMember('Item') );
Assert::same( "{'0Item'}", NPhpHelpers::formatMember('0Item') );

Assert::true( NPhpHelpers::isIdentifier('Item') );
Assert::false( NPhpHelpers::isIdentifier('0Item') );
