<?php

/**
 * Test: NValidators::is()
 *
 * @author     David Grudl
 * @package    Nette\Utils
 * @subpackage UnitTests
 */



require dirname(__FILE__) . '/../bootstrap.php';



Assert::false( NValidators::is(TRUE, 'int') );
Assert::false( NValidators::is('1', 'int') );
Assert::true( NValidators::is(1, 'integer') );
Assert::true( NValidators::is(1, 'int') );
Assert::false( NValidators::is(1, 'int:)') );
Assert::false( NValidators::is(1, 'int:0') );
Assert::true( NValidators::is(1, 'int:1') );
Assert::true( NValidators::is(0, 'int:0') );
Assert::true( NValidators::is(1, 'int:..') );
Assert::false( NValidators::is(1, 'int:0..0') );
Assert::true( NValidators::is(1, 'int:0..1') );
Assert::true( NValidators::is(1, 'int:0..') );
Assert::false( NValidators::is(1, 'int:..0') );
Assert::true( NValidators::is(1, 'int:..1') );
Assert::true( NValidators::is(0, 'int:..0') );
Assert::true( NValidators::is(-1, 'int:..0') );


Assert::false( NValidators::is(TRUE, 'float') );
Assert::false( NValidators::is('1', 'float') );
Assert::false( NValidators::is(1, 'float') );
Assert::true( NValidators::is(1.0, 'float') );


Assert::false( NValidators::is(TRUE, 'number') );
Assert::false( NValidators::is('1', 'number') );
Assert::true( NValidators::is(1, 'number') );
Assert::true( NValidators::is(1.0, 'number') );


Assert::false( NValidators::is(TRUE, 'numeric') );
Assert::true( NValidators::is('1', 'numeric') );
Assert::true( NValidators::is('-1', 'numeric') );
Assert::true( NValidators::is('-1.5', 'numeric') );
Assert::true( NValidators::is('-.5', 'numeric') );
Assert::false( NValidators::is('1e6', 'numeric') );
Assert::true( NValidators::is(1, 'numeric') );
Assert::true( NValidators::is(1.0, 'numeric') );


Assert::false( NValidators::is(TRUE, 'numericint') );
Assert::true( NValidators::is('1', 'numericint') );
Assert::true( NValidators::is('-1', 'numericint') );
Assert::false( NValidators::is('-1.5', 'numericint') );
Assert::false( NValidators::is('-.5', 'numericint') );
Assert::false( NValidators::is('1e6', 'numericint') );
Assert::true( NValidators::is(1, 'numericint') );
Assert::false( NValidators::is(1.0, 'numericint') );


Assert::false( NValidators::is(1, 'bool') );
Assert::true( NValidators::is(TRUE, 'bool') );
Assert::true( NValidators::is(FALSE, 'bool') );
Assert::true( NValidators::is(TRUE, 'boolean') );
Assert::true( NValidators::is(TRUE, 'bool:1') );
Assert::false( NValidators::is(TRUE, 'bool:0') );
Assert::false( NValidators::is(FALSE, 'bool:1') );
Assert::true( NValidators::is(FALSE, 'bool:0') );
Assert::true( NValidators::is(FALSE, 'bool:0..1') );


Assert::false( NValidators::is(1, 'string') );
Assert::true( NValidators::is('', 'string') );
Assert::true( NValidators::is('hello', 'string') );
Assert::true( NValidators::is('hello', 'string:5') );
Assert::false( NValidators::is('hello', 'string:4') );
Assert::true( NValidators::is('hello', 'string:4..') );
Assert::false( NValidators::is('hello', 'string:1..4') );


Assert::false( NValidators::is(1, 'unicode') );
Assert::true( NValidators::is('', 'unicode') );
Assert::true( NValidators::is('hello', 'unicode') );
Assert::false( NValidators::is("hello\xFF", 'unicode') );
Assert::true( NValidators::is('hello', 'unicode:5') );
Assert::false( NValidators::is('hello', 'unicode:4') );
Assert::true( NValidators::is('hello', 'unicode:4..') );
Assert::false( NValidators::is('hello', 'unicode:1..4') );


Assert::false( NValidators::is(null, 'array') );
Assert::true( NValidators::is(array(), 'array') );
Assert::true( NValidators::is(array(), 'array:0') );
Assert::true( NValidators::is(array(1), 'array:1') );
Assert::true( NValidators::is(array(1), 'array:0..') );
Assert::true( NValidators::is(array(), 'array:..1') );


Assert::false( NValidators::is(NULL, 'list') );
Assert::true( NValidators::is(array(), 'list') );
Assert::true( NValidators::is(array(1), 'list') );
Assert::true( NValidators::is(array('a', 'b', 'c'), 'list') );
Assert::false( NValidators::is(array(4 => 1, 2, 3), 'list') );
Assert::false( NValidators::is(array(1 => 'a', 0 => 'b'), 'list') );
Assert::false( NValidators::is(array('key' => 'value'), 'list') );
$arr = array();
$arr[] = & $arr;
Assert::true( NValidators::is($arr, 'list') );
Assert::false( NValidators::is(array(1,2,3), 'list:4') );


Assert::false( NValidators::is(null, 'object') );
Assert::true( NValidators::is(new stdClass, 'object') );


Assert::false( NValidators::is(null, 'scalar') );
Assert::false( NValidators::is(array(), 'scalar') );
Assert::true( NValidators::is(1, 'scalar') );


Assert::false( NValidators::is(null, 'callable') );
Assert::false( NValidators::is(array(), 'callable') );
Assert::false( NValidators::is(1, 'callable') );
Assert::false( NValidators::is('', 'callable') );
Assert::true( NValidators::is('hello', 'callable') );
Assert::false( NValidators::is(array('hello'), 'callable') );
Assert::true( NValidators::is(array('hello', 'world'), 'callable') );


Assert::false( NValidators::is(0, 'null') );
Assert::true( NValidators::is(null, 'null') );


Assert::false( NValidators::is('', 'email') );
Assert::false( NValidators::is('hello', 'email') );
Assert::true( NValidators::is('hello@world.cz', 'email') );


Assert::false( NValidators::is('', 'url') );
Assert::false( NValidators::is('hello', 'url') );
Assert::false( NValidators::is('nette.org', 'url') );
Assert::true( NValidators::is('http://nette.org/path', 'url') );
Assert::true( NValidators::is('https://www.nette.org/path', 'url') );


Assert::true( NValidators::is(0, 'none') );
Assert::true( NValidators::is('', 'none') );
Assert::true( NValidators::is(NULL, 'none') );
Assert::true( NValidators::is(FALSE, 'none') );
Assert::false( NValidators::is('0', 'none') );
Assert::true( NValidators::is(array(), 'none') );


Assert::true( NValidators::is('', 'pattern') );
Assert::true( NValidators::is('  123', 'pattern:\s+\d+') );
Assert::false( NValidators::is('  123x', 'pattern:\s+\d+') );


Assert::false( NValidators::is('', 'alnum') );
Assert::false( NValidators::is('a-1', 'alnum') );
Assert::true( NValidators::is('a1', 'alnum') );
Assert::true( NValidators::is('a1', 'alnum:2') );


Assert::false( NValidators::is('', 'alpha') );
Assert::false( NValidators::is('a1', 'alpha') );
Assert::true( NValidators::is('aA', 'alpha') );
Assert::true( NValidators::is('aA', 'alpha:1..3') );


Assert::false( NValidators::is('', 'digit') );
Assert::false( NValidators::is('123x', 'digit') );
Assert::true( NValidators::is('123', 'digit') );
Assert::false( NValidators::is('123', 'digit:..2') );


Assert::false( NValidators::is('', 'lower') );
Assert::false( NValidators::is('Hello', 'lower') );
Assert::true( NValidators::is('hello', 'lower') );
Assert::false( NValidators::is('hello', 'lower:9') );


Assert::false( NValidators::is('', 'upper') );
Assert::false( NValidators::is('Hello', 'upper') );
Assert::true( NValidators::is('HELLO', 'upper') );


Assert::false( NValidators::is('', 'space') );
Assert::false( NValidators::is(' 1', 'space') );
Assert::true( NValidators::is(" \t\r\n", 'space') );


Assert::false( NValidators::is('', 'xdigit') );
Assert::false( NValidators::is('123x', 'xdigit') );
Assert::true( NValidators::is('123aA', 'xdigit') );


Assert::true( NValidators::is(1.0, 'int|float') );
Assert::true( NValidators::is(1, 'int|float') );
Assert::false( NValidators::is('1', 'int|float') );
